"""Data for Home Assistant sensors unit tests."""

from typing import Any
from typing import Dict
from typing import List

discovery_message_expected: List[Dict[str, Any]] = [
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Voltage",
            "unique_id": "mocked_unipi_voltage_1",
            "state_topic": "mocked_unipi/meter/voltage_1/get",
            "qos": 2,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "suggested_area": "Workspace",
                "via_device": "MOCKED UNIPI",
            },
            "device_class": "voltage",
            "force_update": True,
            "state_class": "measurement",
            "unit_of_measurement": "V",
        },
        "topic": "homeassistant/sensor/mocked_unipi_voltage_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Current",
            "unique_id": "mocked_unipi_current_1",
            "state_topic": "mocked_unipi/meter/current_1/get",
            "qos": 2,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "suggested_area": "Workspace",
                "via_device": "MOCKED UNIPI",
            },
            "device_class": "current",
            "force_update": True,
            "state_class": "measurement",
            "unit_of_measurement": "A",
        },
        "topic": "homeassistant/sensor/mocked_unipi_current_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Active Power",
            "unique_id": "mocked_unipi_active_power_1",
            "state_topic": "mocked_unipi/meter/active_power_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_active_power_1/config",
    },
    {
        "message": {
            "name": "MOCKED_FRIENDLY_NAME - APPARENT_POWER",
            "unique_id": "mocked_unipi_mocked_id_apparent_power",
            "state_topic": "mocked_unipi/meter/apparent_power_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - MOCKED AREA 3",
                "identifiers": "MOCKED Eastron SDM120M - MOCKED AREA 3",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "MOCKED AREA 3",
            },
            "object_id": "mocked_id_apparent_power",
            "icon": "mdi:power-standby",
            "device_class": "apparent_power",
            "state_class": "measurement",
            "unit_of_measurement": "VA",
        },
        "topic": "homeassistant/sensor/mocked_unipi_mocked_id_apparent_power/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Reactive Power",
            "unique_id": "mocked_unipi_reactive_power_1",
            "state_topic": "mocked_unipi/meter/reactive_power_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "total",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_reactive_power_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Power Factor",
            "unique_id": "mocked_unipi_power_factor_1",
            "state_topic": "mocked_unipi/meter/power_factor_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power_factor",
            "state_class": "measurement",
        },
        "topic": "homeassistant/sensor/mocked_unipi_power_factor_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Phase Angle",
            "unique_id": "mocked_unipi_phase_angle_1",
            "state_topic": "mocked_unipi/meter/phase_angle_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "state_class": "measurement",
        },
        "topic": "homeassistant/sensor/mocked_unipi_phase_angle_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Frequency",
            "unique_id": "mocked_unipi_frequency_1",
            "state_topic": "mocked_unipi/meter/frequency_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "frequency",
            "state_class": "measurement",
            "unit_of_measurement": "Hz",
        },
        "topic": "homeassistant/sensor/mocked_unipi_frequency_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Import Active Energy",
            "unique_id": "mocked_unipi_import_active_energy_1",
            "state_topic": "mocked_unipi/meter/import_active_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "energy",
            "state_class": "total",
            "unit_of_measurement": "kWh",
        },
        "topic": "homeassistant/sensor/mocked_unipi_import_active_energy_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Export Active Energy",
            "unique_id": "mocked_unipi_export_active_energy_1",
            "state_topic": "mocked_unipi/meter/export_active_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "energy",
            "state_class": "measurement",
            "unit_of_measurement": "kWh",
        },
        "topic": "homeassistant/sensor/mocked_unipi_export_active_energy_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Import Reactive Energy",
            "unique_id": "mocked_unipi_import_reactive_energy_1",
            "state_topic": "mocked_unipi/meter/import_reactive_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "state_class": "total",
            "unit_of_measurement": "kvarh",
        },
        "topic": "homeassistant/sensor/mocked_unipi_import_reactive_energy_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Export Reactive Energy",
            "unique_id": "mocked_unipi_export_reactive_energy_1",
            "state_topic": "mocked_unipi/meter/export_reactive_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "state_class": "total",
            "unit_of_measurement": "kvarh",
        },
        "topic": "homeassistant/sensor/mocked_unipi_export_reactive_energy_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Total System Power Demand",
            "unique_id": "mocked_unipi_total_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/total_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_total_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Maximum Total System Power Demand",
            "unique_id": "mocked_unipi_maximum_total_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_total_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "total",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_maximum_total_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Import System Power Demand",
            "unique_id": "mocked_unipi_import_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/import_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_import_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Maximum Import System Power Demand",
            "unique_id": "mocked_unipi_maximum_import_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_import_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_maximum_import_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Export System Power Demand",
            "unique_id": "mocked_unipi_export_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/export_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_export_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Maximum Export System Power Demand",
            "unique_id": "mocked_unipi_maximum_export_system_power_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_export_system_power_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "power",
            "state_class": "measurement",
            "unit_of_measurement": "W",
        },
        "topic": "homeassistant/sensor/mocked_unipi_maximum_export_system_power_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Current Demand",
            "unique_id": "mocked_unipi_current_demand_1",
            "state_topic": "mocked_unipi/meter/current_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "current",
            "state_class": "measurement",
            "unit_of_measurement": "A",
        },
        "topic": "homeassistant/sensor/mocked_unipi_current_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Maximum Current Demand",
            "unique_id": "mocked_unipi_maximum_current_demand_1",
            "state_topic": "mocked_unipi/meter/maximum_current_demand_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "current",
            "state_class": "measurement",
            "unit_of_measurement": "A",
        },
        "topic": "homeassistant/sensor/mocked_unipi_maximum_current_demand_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Total Active Energy",
            "unique_id": "mocked_unipi_total_active_energy_1",
            "state_topic": "mocked_unipi/meter/total_active_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "device_class": "energy",
            "state_class": "total",
            "unit_of_measurement": "kWh",
        },
        "topic": "homeassistant/sensor/mocked_unipi_total_active_energy_1/config",
    },
    {
        "message": {
            "name": "MOCKED Eastron SDM120M - Workspace: Total Reactive Energy",
            "unique_id": "mocked_unipi_total_reactive_energy_1",
            "state_topic": "mocked_unipi/meter/total_reactive_energy_1/get",
            "qos": 2,
            "force_update": True,
            "device": {
                "name": "MOCKED Eastron SDM120M - Workspace",
                "identifiers": "MOCKED Eastron SDM120M - Workspace",
                "model": "SDM120M",
                "sw_version": "202.04",
                "manufacturer": "Eastron",
                "via_device": "MOCKED UNIPI",
                "suggested_area": "Workspace",
            },
            "state_class": "total",
            "unit_of_measurement": "kvarh",
        },
        "topic": "homeassistant/sensor/mocked_unipi_total_reactive_energy_1/config",
    },
]
